patch for drivers/sound/sb_card.c to recognize mpu_io bootline parameter

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Dear developes,

I could not find any maintainer for the sound blaster audio driver so I chose
to address this to the kernel developer list.

Problem:

Unlike in kernels 2.2.X it seems no longer possible to specify during kernel
configuration the sound blaster mpu io address. This might be necessary with
old non-PNP ISA sb cards when not using the sb driver as a kernel module but
directly compiling it in.
The alternative would be to specify that address on boot time via a kernel
option; however sb= supports sb IO address, IRQ, DMA and DMA16 only.

Solution:

Add support for a fifth parameter to sb= representing the sb mpu IO address.

This is what the following patch, developed on Linux 2.4.31, does:


--- drivers/sound/sb_card.c.orig        2005-08-20 23:37:09.000000000 +0200
+++ drivers/sound/sb_card.c     2005-08-20 23:39:10.000000000 +0200
@@ -1019,8 +1019,8 @@
 #ifndef MODULE
 static int __init setup_sb(char *str)
 {
-       /* io, irq, dma, dma2 - just the basics */
-       int ints[5];
+       /* io, irq, dma, dma2, mpu io - just the basics */
+       int ints[6];
 
        str = get_options(str, ARRAY_SIZE(ints), ints);
 
@@ -1028,6 +1028,7 @@
        irq     = ints[2];
        dma     = ints[3];
        dma16   = ints[4];
+       mpu_io  = ints[5];
 
        return 1;
 }




I could not find any documentation that would mention sb=, let alone its
parameters. If that one exists nonetheless it would of course also have to be
complemented.

Georg




-- 
Georg Schwarz    http://home.pages.de/~schwarz/
 [email protected]     +49 178 8545053
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]
  Powered by Linux